@@ -49,6 +49,8 @@
 #include <QTranslator>
 #include <QCommandLineParser>
 #include <QCommandLineOption>
+#include "uniqueapplication.h"
+#include <QString>
 
 static pa_context* context = NULL;
 static pa_mainloop_api* api = NULL;
@@ -645,7 +647,13 @@ int main(int argc, char *argv[]) {
 
     signal(SIGPIPE, SIG_IGN);
 
-    QApplication app(argc, argv);
+    UniqueApplication app(argc, argv);
+
+    if(app.active())
+        return 0;
+
+    app.setOrganizationName(QStringLiteral("pavucontrol-qt"));
+
 
     QString locale = QLocale::system().name();
     QTranslator qtTranslator;
